@@ -11,13 +11,15 @@ from fastapi_helpers.crud import BaseCrud, to_dict
 from fastapi_helpers.security import Encoder
 from fastapi_helpers.settings import DefaultSettings
 from fastapi_helpers.db import DbConfig
+from fastapi_helpers.db.seeders import DbSeeder
 
-__version__ = "0.0.13"
+__version__ = "0.0.15"
 
 __all__ = [
     "Worker",
     "DefaultLogger",
     "DbConfig",
+    "DbSeeder",
     "HeadersMiddleware",
     "DefaultModelRouter",
     "load_data_callback",
