@@ -1,6 +1,6 @@
 from ormar import Model
 from fastapi_helpers.routes.Paginate import paginate_object, load_data_callback, Pagination
-from typing import Any, List, Type
+from typing import Any, List, Type, Optional, Dict, Union
 
 
 class BaseCrud():
@@ -10,7 +10,7 @@ class BaseCrud():
     def __init__(self, model: Type[Model]) -> None:
         self.model = model
 
-    async def load_data(self, result=[]) -> Any:
+    async def load_data(self, result:List[Model] =[]) -> List[Model]:
         return await load_data_callback(result)
 
     async def get_list(self, options: Pagination) -> List[Any]:
@@ -35,7 +35,7 @@ class BaseCrud():
             (self.load_data, {})
         )
 
-    async def get(self, id: str) -> Any:
+    async def get(self, id: Optional[Union[int, str]]) -> Any:
         options = Pagination()
         options.limit = 1
         options.filters = {'id': id}
@@ -48,13 +48,23 @@ class BaseCrud():
             return objs[0]
         return None
 
-    async def create(self, model_in) -> Any:
+    async def get_or_create(self, model_in: Optional[Union[Dict, Model]]) -> Optional[Model]:
+        params = to_dict(model_in)
+        obj = self.model(**params)
+        obj = await obj.get_or_create()
+        return obj
+
+    async def create(self, model_in: Optional[Union[Dict, Model]]) -> Optional[Model]:
         params = to_dict(model_in)
         obj = self.model(**params)
         obj = await obj.save()
         return obj
 
-    async def update(self, id, model_in) -> Any:
+    async def update(
+        self,
+        id: Optional[Union[int, str]],
+        model_in: Optional[Union[Dict, Model]]
+    ) -> Optional[Model]:
         params = to_dict(model_in)
         obj = await self.model.objects.get_or_none(id=id)
         if(obj is None):
@@ -62,7 +72,7 @@ class BaseCrud():
         obj = await obj.update(**params)
         return obj
 
-    async def delete(self, id) -> Any:
+    async def delete(self, id: Optional[Union[int, str]]) -> Optional[Model]:
         obj = await self.model.objects.get_or_none(id=id)
         if(obj is None):
             return None
